==> vtk6-6.3.0-2-aarch64.pkg.tar.xz: vtk/vtkDeformPointSet.java <==
// java wrapper for vtkDeformPointSet object
//

package vtk;
import vtk.*;

public class vtkDeformPointSet extends vtkPointSetAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetControlMeshData_2(vtkPolyData id0);
  public void SetControlMeshData(vtkPolyData id0)
    { SetControlMeshData_2(id0); }

  private native long GetControlMeshData_3();
  public vtkPolyData GetControlMeshData() {
    long temp = GetControlMeshData_3();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetControlMeshConnection_4(vtkAlgorithmOutput id0);
  public void SetControlMeshConnection(vtkAlgorithmOutput id0)
    { SetControlMeshConnection_4(id0); }

  private native void SetInitializeWeights_5(int id0);
  public void SetInitializeWeights(int id0)
    { SetInitializeWeights_5(id0); }

  private native int GetInitializeWeights_6();
  public int GetInitializeWeights()
    { return GetInitializeWeights_6(); }

  private native void InitializeWeightsOn_7();
  public void InitializeWeightsOn()
    { InitializeWeightsOn_7(); }

  private native void InitializeWeightsOff_8();
  public void InitializeWeightsOff()
    { InitializeWeightsOff_8(); }

  public vtkDeformPointSet() { super(); }

  public vtkDeformPointSet(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-aarch64.pkg.tar.xz: vtk/vtkDeformPointSet.java <==
// java wrapper for vtkDeformPointSet object
//

package vtk;
import vtk.*;

public class vtkDeformPointSet extends vtkPointSetAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetControlMeshData_2(vtkPolyData id0);
  public void SetControlMeshData(vtkPolyData id0)
    { SetControlMeshData_2(id0); }

  private native long GetControlMeshData_3();
  public vtkPolyData GetControlMeshData() {
    long temp = GetControlMeshData_3();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetControlMeshConnection_4(vtkAlgorithmOutput id0);
  public void SetControlMeshConnection(vtkAlgorithmOutput id0)
    { SetControlMeshConnection_4(id0); }

  private native void SetInitializeWeights_5(int id0);
  public void SetInitializeWeights(int id0)
    { SetInitializeWeights_5(id0); }

  private native int GetInitializeWeights_6();
  public int GetInitializeWeights()
    { return GetInitializeWeights_6(); }

  private native void InitializeWeightsOn_7();
  public void InitializeWeightsOn()
    { InitializeWeightsOn_7(); }

  private native void InitializeWeightsOff_8();
  public void InitializeWeightsOff()
    { InitializeWeightsOff_8(); }

  public vtkDeformPointSet() { super(); }

  public vtkDeformPointSet(long id) { super(id); }
  public native long   VTKInit();

}
